==> minitube-0.9.tar.gz: minitube/locale/hr_HR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr_HR">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Postoji život izvan preglednika!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Verzija %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Ovo je &quot;Technology Preview&quot;izdanje, te ne očekujte da bude savršeno.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Prijavite sve bugove i posaljite svoje ideje na %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je besplatan program ali njegov razvoj uzima dragocjeno vrijeme.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Molimo &lt;a href=&apos;%1 &apos;&gt;donirajte preko PayPal-a&lt;/a&gt; za podršku i kontinuiran razvoj %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikonu je dizajnirao %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompaktni način pridonio je %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP proxy podršku je pridonio %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Windows verziju uradio je %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Preveo je %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Objavljeno je pod &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Što ste oduvijek željeli znati o %1 a nikad se niste usudili pitati</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Očisti</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Pretraživanje...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Pokaži još jedan %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nema videa</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nema više videa</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Natrag</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Idi na prethodni prikaz</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stani</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Zaustavi playback i vrati se na pretraživanje</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Preskoči</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Preskoči na sljedeći video</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pauziraj playback</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Cijeli ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Gledaj preko cijelog ekrana</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Kompaktan način</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Sakrij naslove i alatnu traku</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Otvori YouTube video stranicu</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Ukloni</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Ukloni odabrane snimke sa playliste</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Premjesti gore</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Premjesti gore selektirane snimke u playlistu</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Premjesti &amp;Dolje</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Premjesti dolje selektirane snimke u playlistu</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Odustani</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Pozdrav</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Web stranica</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na internetu</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>&amp;Donirajte preko PayPal-a</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Molimo potporu u daljnjem razvoju %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info o %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pretraga</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Isključi zvuk</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Playlista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pritisnite %1 za povećati zvuk, %2 za smanjiti zvuk</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otvaranje %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Fatalna greška: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Greška: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Pusti</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Nastavi playback</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Izlaz&amp;Cijeli ekran</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Preostalo vrijeme: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Jačina zvuka je na %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Zvuk je isključen</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Zvuk je uključen</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Visoka rezolucija videa je uključena</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Visoka rezolucija videa je isključena</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>Odabrani video je u visokoj rezoluciji</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>Odabrani video nije u visokoj rezoluciji</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Najznačajniji</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Najnoviji</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Najgledaniji</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Gledate &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Greška u mreži:%1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 gledano</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pretraga</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Dobro došli &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Unesite ključnu riječ za početak gledanja videa.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Gledaj</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Nedavno gledano</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Nova verzija %1 je dostupna. Molimo &lt;a href=&apos;%2&apos;&gt;nadogradite verziju %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Osjećajte se udobno</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Postavke</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Greška u mreži:%1 za %2</translation>
    </message>
</context>
</TS>

==> minitube-1.0.tar.gz: minitube/locale/hr_HR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr_HR">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Postoji život izvan preglednika!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Verzija %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Ovo je &quot;Technology Preview&quot;izdanje, te ne očekujte da bude savršeno.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Prijavite sve bugove i posaljite svoje ideje na %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je besplatan program ali njegov razvoj uzima dragocjeno vrijeme.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Molimo &lt;a href=&apos;%1 &apos;&gt;donirajte preko PayPal-a&lt;/a&gt; za podršku i kontinuiran razvoj %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikonu je dizajnirao %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompaktni način pridonio je %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP proxy podršku je pridonio %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Windows verziju uradio je %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Preveo je %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Objavljeno je pod &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Što ste oduvijek željeli znati o %1 a nikad se niste usudili pitati</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Očisti</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Pretraživanje...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Pokaži još jedan %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nema videa</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nema više videa</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Natrag</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Idi na prethodni prikaz</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stani</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Zaustavi playback i vrati se na pretraživanje</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Preskoči</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Preskoči na sljedeći video</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pauziraj playback</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Cijeli ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Gledaj preko cijelog ekrana</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Kompaktan način</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Sakrij naslove i alatnu traku</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Otvori YouTube video stranicu</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Ukloni</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Ukloni odabrane snimke sa playliste</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Premjesti gore</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Premjesti gore selektirane snimke u playlistu</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Premjesti &amp;Dolje</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Premjesti dolje selektirane snimke u playlistu</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Odustani</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Pozdrav</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Web stranica</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na internetu</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;Donirajte preko PayPal-a</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Molimo potporu u daljnjem razvoju %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info o %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pretraga</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Isključi zvuk</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Playlista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pritisnite %1 za povećati zvuk, %2 za smanjiti zvuk</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otvaranje %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Fatalna greška: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Greška: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Pusti</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Nastavi playback</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Izlaz&amp;Cijeli ekran</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Preostalo vrijeme: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Jačina zvuka je na %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Zvuk je isključen</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Zvuk je uključen</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">Visoka rezolucija videa je uključena</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">Visoka rezolucija videa je isključena</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Odabrani video je u visokoj rezoluciji</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Odabrani video nije u visokoj rezoluciji</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Najznačajniji</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Najnoviji</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Najgledaniji</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Gledate &quot;%1&quot;</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Greška u mreži:%1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 gledano</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pretraga</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Dobro došli &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Unesite ključnu riječ za početak gledanja videa.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Gledaj</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Nedavno gledano</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Nova verzija %1 je dostupna. Molimo &lt;a href=&apos;%2&apos;&gt;nadogradite verziju %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Osjećajte se udobno</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Postavke</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Greška u mreži:%1 za %2</translation>
    </message>
</context>
</TS>
